@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "11.0.21+9" },
-            { "jdk", "11.0.21" },
-            { "release", "11.0.21" },
+            { "full", "17.0.8.1+1" },
+            { "jdk", "17.0.8.1" },
+            { "release", "17.0.8.1" },
         };
     }
 }
